#
# spec file for package virt-scenario
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define pythons python3

Name:           virt-scenario
Version:        2.1.2
Release:        1.1
Summary:        Tool to create XML guest configuration and prepare the host for a scenario
License:        GPL-3.0-or-later
Group:          System/Management
URL:            https://github.com/aginies/virt-scenario
Source:         %{name}-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module libvirt-python}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pyudev}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
#Buildrequires:	pandoc
BuildArch:      noarch
Requires:       python-PyYAML
Requires:       python-curses
Requires:       python-libvirt-python
Requires:       python-psutil
Requires:       python-pyudev
Provides:       virt-scenario = %{version}
%python_subpackages

%description
A tool to generate a customized libvirt XML guest and prepare the host.
The idea is to improve the experience of usage compared to a basic setting.
This tool also simplifies the creation of secure VM (AMD SEV).

%package        gtk
Summary:        Gtk interface %{name}
Requires:       %{name} = %{version}-%{release}

%description    gtk
This is the Gtk interface for %{name}.

%prep
%autosetup

%build
%python_build

%install
%python_install
# move yaml file to /etc/virt-scenario
mkdir -p %{buildroot}%{_sysconfdir}/%{name}/vmconfig
mv %{buildroot}%{_datadir}/%{name}/*.yaml %{buildroot}%{_sysconfdir}/%{name}/
mv src/demo_api_usage.py %{buildroot}%{_datadir}/%name/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc ChangeLog README.md
%{_bindir}/virt-scenario
%{_bindir}/virt-scenario-launch
%{_bindir}/virt-select-firmware
%{python_sitelib}/virtscenario
%{python_sitelib}/virt_select_firmware
%{python_sitelib}/virtscenario_launch
%{python_sitelib}/*.egg-info
%attr(0644,root,root) %{_datadir}/%name
%{_mandir}/man1/%{name}.1%{ext_man}
%{_mandir}/man1/%{name}-settings.1%{ext_man}
%attr(0644,root,root) %{_datadir}/%{name}/
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}

%files gtk
%{_bindir}/virt-scenario-gtk
%{python_sitelib}/vsmygtk

%changelog
* Mon Jul 31 2023 Antoine Ginies <aginies@suse.com>
- version 2.1.2:
  * by default don't create virtio input devices using the configuration
    file as this overwrites scenario default values and can cause some
    issues.
* Mon Jun 19 2023 Antoine Ginies <aginies@suse.com>
- version 2.1.1:
  * remove 'terminate' button in the scenario selection page
  * storage window now preload previous data if they have been
    already set
  * improve encryption password checks
  * cleanup some code
* Wed Jun 14 2023 Antoine Ginies <aginies@suse.com>
- version 2.1.0:
  * various fixes around hypervisor selection
  * force hypervisor selection before choosing machine type or virtual net
  * use machine list from the hypervisor capabilities (remove hardcoded list)
  * check virtual machine name (only alphanumeric)
  * various other cosmetics fixes
  * GTK:
  - only support localhost hypervisor due to limitation in authentication
  - add some more tooltips
  - improve layout: help on disk cache and some others
* Wed Jun  7 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.8:
  * disk image encryption is now supported
  * if image encryption is enabled the default mode will be
    preparing Guest and Host as the secret uuid is needed
  * overwrite mode delete previous domain on the hypervisor
    to avoid any previous Guest XML definition
  * clean up some code
* Tue Jun  6 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.7:
  * add more info and debug in case of failure
  * fix issues on PDH and certificate
  * ! Image encryption is currently broken (encrypt.key-secret)
    you should disable it
* Mon Jun  5 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.5:
  * exit in gtk mode if no connection to libvirt
  * update man page
* Wed May 31 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.4:
  * display the force_sev page only in securevm scenario
  * typo fixes
  * remove pprint debug
  * update API demo script
  * switch default VM image size to 8GiB instead of 20GiB
* Wed May 31 2023 Antoine Ginies <aginies@suse.com>
- fix missing directory /etc/virt-scenario/vmconfig
* Wed May 24 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.3:
  * In Interactive mode add settings for:
  - Image Format
  - Image Size
  - Encryption
  - Cache mode
  * fix diskpath bug
* Wed May 24 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.2:
  * fix encrypted VM disk image bug
  * add support for memory backing
  * add support for disk format (qcow2/raw)
  * Gtk:
  - add more tooltips
  - add support for the disk image encryption password
  - fix some wrong layout
  - remove all colors to be more colorblind compliant
  * remove some debug info
* Mon May 22 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.1:
  * continue clean up of the code
  * pylint checks
* Wed May 17 2023 Jan Engelhardt <jengelh@inai.de>
- Repair bad grammar in descriptions.
- Trim old specfile constructs.
* Wed May 17 2023 Antoine Ginies <aginies@suse.com>
- version 2.0.0:
  * major re-organization of the code and cleanup
  * usable as an API (demo file available)
  * add a Gtk interface
  * add more parameters around storage
  * split into a subpackage for the Gtk interface
* Wed Mar 29 2023 Antoine Ginies <aginies@suse.com>
- version 1.0.6:
  * fix (bsc#1209862): virt-scenario-launch can't stop or get status
    on virtual machine
  * fix wrong way to call print_error
* Wed Mar 29 2023 Antoine Ginies <aginies@suse.com>
- version 1.0.5:
  * force_sev now can be disabled (bsc#1209865)
  * check /dev/tpm0 exist before using it (bsc#1209863)
  * switch usage of print_title and print_summary
  * simplify function show_how_to_use()
  * avoid redefining bytes
  * pylint fixes
* Fri Mar 24 2023 Antoine Ginies <aginies@suse.com>
- version 1.0.4:
  * change default configstore to /etc/virt-scenario/vmconfig
    this is needed to automatically save the config in case of usage
    of a container.
* Fri Mar 24 2023 Antoine Ginies <aginies@suse.com>
- version 1.0.3:
  * fix buggy VM image name in XML config
  * Add more information in the documentation (step by step securevm)
* Thu Mar 23 2023 Antoine Ginies <aginies@suse.com>
- version 1.0.2:
  * fix buggy vmimage option (error if not used)
  * summary is displayed at the end in case of differences
  * improve user password input for VM encrypted image
  * some typo fixes
* Wed Mar 22 2023 Antoine Ginies <aginies@suse.com>
- version 1.0.1:
  * user can specify a VM image to use instead of creating one
* Tue Mar 21 2023 Antoine Ginies <aginies@suse.com>
- Major version 1.0.0:
  * various SEV fixes
  * improve force_sev mode
  * update all documentation
  * various pylint fixes
- add requires on python-psutil
* Tue Mar 21 2023 Antoine Ginies <aginies@suse.com>
- fix memory user issue
* Mon Mar 20 2023 Antoine Ginies <aginies@suse.com>
- version 0.7.6:
  * add support for virtual network selection (vnet)
  * add force_sev to extract a local PDH (not recommended: for testing purposes)
  * improve connect to libvirtd socket (more info)
  * fix memory_pin issue while user was setting memory
  * fixes around bootdev
  * various other bug fixes
* Thu Mar 16 2023 Antoine Ginies <aginies@suse.com>
- version 0.7.4:
  * add virt-scenario-launch (Joerg Roedel):
  * tool to launch VMs created by virtscenario and do attestation
    for SecureVMs
  * rewrite and clean some part of the code
  * remove check_container use (no more needed for now)
* Wed Mar 15 2023 Antoine Ginies <aginies@suse.com>
- version 0.7.3:
  * cleanup some code
  * fix wrong info in data encryption
  * fix cluster size error
  * fix default path to image
  * fix missing custom loader
  * fix some wrong output order
* Sat Mar 11 2023 Antoine Ginies <aginies@suse.com>
- version 0.7.2:
  * merge all doc to one README.md
  * adjust path to default configuration (sync with rpm)
  * fix bug in secure_vm (missing LaunchSecurity part)
* Wed Mar  8 2023 Antoine Ginies <aginies@suse.com>
- version 0.7.0:
  * add CD/DVD media installation support
  * add overwrite mode
  * add transparent hugepage support
  * add more checks of external tools
  * add SEV support
  * add a new virt-select-firmware tool
  * update all docs
  * improve various functions and code
  * improve general layout
  * change some defaults settings (check the table in the README.md file)
  * fix some guest/host mode bugs
  * various other bugs/pylint fixes
* Fri Jan 20 2023 Antoine Ginies <aginies@suse.com>
- testing release 0.5.0
* Tue Jan 17 2023 Antoine Ginies <aginies@suse.com>
- first release
